# PyNeval

PyNeval is a user-friendly but flexible command line interface toolbox.
It is designed for **quantitative assessment** on tree-like structures obtained from a neuron reconstruction algorithm.
**Gold standard**, **reconstructed models** as well as **specified metric** options are required as input,
both carefully formatted result and detailed mismatched nodes are provided as output.
Start by reading the Installation Guide and Tutorial for more information.





